| scale_colour_ios_gray_dark | R Documentation |
These scales are based on dark gray palette of iOS system colors. They have only been implemented in sfthemes because I wanted to bring all the color palettes mentioned in the Apple's HIG.
Warning:
iOS gray colors are not necessary suitable for general
plotting; so consider your use-case carefully before adapting them. You can
loosely compare them to ggplot2::scale_alpha().
scale_colour_ios_gray_dark(accessible = FALSE, ...) scale_fill_ios_gray_dark(accessible = FALSE, ...)
accessible |
Indicates whether the accessible set of colors should be used |
... |
Arguments passed on to
|
Other colour scales:
scale_colour_ios_dark(),
scale_colour_ios_gray_light(),
scale_colour_ios_light(),
scale_colour_macos_dark(),
scale_colour_macos_light(),
scale_colour_watchos_dark()
## Not run:
library(ggplot2)
ggplot(mtcars, aes(y = mpg, x = as.factor(cyl))) +
geom_boxplot(aes(color = as.factor(cyl), fill = as.factor(cyl))) +
labs(x = "Miles Per Gallon", y = "MPG",
fill = "Number of Cylinders",
color = "Number of Cylinders",
title = "Fuel Economy",
subtitle = "Fuel economy declines as engines gets bigger",
caption = "Data from the 1974 Motor Trend US magazine.") +
theme_sf_dark() +
scale_fill_ios_gray_dark() +
scale_colour_ios_gray_dark()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.